#   Differential expression analysis with limma
library(GEOquery)
library(limma)
library(tidyverse)

# load series and platform data from GEO
gset <- getGEO("GSE58162", GSEMatrix = TRUE, AnnotGPL = FALSE)

if (length(gset) > 1) {
  idx <- grep("GPL10904", attr(gset, "names"))
}  else {
  idx <- 1
}

gset <- gset[[idx]]

# make proper column names to match toptable
fvarLabels(gset) <- make.names(fvarLabels(gset))

# group membership for all samples
gsms <- "111000"
sml <- strsplit(gsms, split = "")[[1]]

# log2 transformation
ex <- exprs(gset)
qx <- as.numeric(quantile(ex, c(0., 0.25, 0.5, 0.75, 0.99, 1.0), na.rm = T))
logc <- (qx[5] > 100) ||
          (qx[6] - qx[1] > 50 && qx[2] > 0)

if (logc) {
  ex[which(ex <= 0)] <- NaN
  exprs(gset) <- log2(ex)
}

# assign samples to groups and set up design matrix
gs <- factor(sml)
groups <- make.names(c("TRTM", "CTRL"))
levels(gs) <- groups
gset$group <- gs
design <- model.matrix(~group + 0, gset)
colnames(design) <- levels(gs)

nall <- nrow(gset)
gset <- gset[complete.cases(exprs(gset)), ]

# calculate precision weights
v <- vooma(gset, design)
v$genes <- fData(gset) # attach gene annotations

# fit linear model
fit  <- lmFit(v) #Fit linear model for each gene given a series of arrays

# set up contrasts of interest and recalculate model coefficients
cts <- paste(groups[1], groups[2], sep = "-")
cont_matrix <- makeContrasts(contrasts = cts, levels = design)

# Given a linear model fit to microarray data,
# compute estimated coefficients and standard errors
# for a given set of contrasts.
fit2 <- contrasts.fit(fit, cont_matrix)

# Compute moderated t,F,and log-odds
# by empirical bayes moderation of se  towards a global value
fit2 <- eBayes(fit2, 0.01)

tt <- topTable(fit2, adjust = "fdr", sort.by = "B", number = Inf)

#Save significant DEGS
sign_tt5 <- filter(tt, adj.P.Val <= 0.05)
write_csv(sign_tt5, file = "File_S4.csv")
# prob remove this
# sign_tt10 <- filter(tt, adj.P.Val <= 0.1)
# inner_join(dum,sign_tt5, by = c("Gene" = "ID")) %>% ggplot() + aes(x=`Ratio: (ASA) / (DMSO)`, y=logFC) + geom_point() + geom_vline(xintercept=1) + geom_hline(yintercept=0) + ggrepel::geom_label_repel(aes(label = Gene), max.overlaps=20)
